@@ -27,22 +27,20 @@ use warnings;
 use strict;
 use Siebel::Srvrmgr::Daemon::Heavy;
 use Siebel::Srvrmgr::ListParser::Output::ListComp::Server;
-use Siebel::Srvrmgr::ListParser::Output::ListParams;
+use Siebel::Srvrmgr::ListParser::Output::Tabular::ListParams;
 use Siebel::Srvrmgr::Daemon::Command;
 use Siebel::Srvrmgr::Exporter::ListCompDef;
 use Siebel::Srvrmgr::Exporter::ListComp;
 use Siebel::Srvrmgr::Exporter::ListCompTypes;
 use File::Spec;
 use Getopt::Std;
-use feature qw(say);
-#use Term::Pulse;
+use Term::Pulse;
+use Siebel::Srvrmgr::Exporter;
 
 $Getopt::Std::STANDARD_HELP_VERSION = 2;
 
 # for stopping Term::Pulse correctly
-$SIG{INT}     = sub { die "Caught interrupt signal" };
-
-our $VERSION = 1;
+$SIG{INT} = sub { die "Caught interrupt signal" };
 
 sub HELP_MESSAGE {
 
@@ -50,13 +48,13 @@ sub HELP_MESSAGE {
 
     if ( ( defined($option) ) and ( ref($option) eq '' ) ) {
 
-        say "'-$option' parameter cannot be null";
+        print "'-$option' parameter cannot be null\n";
 
     }
 
-    say <<BLOCK;
+    print <<BLOCK;
 
-export_comps - version $VERSION
+export_comps - version $Siebel::Srvrmgr::Exporter::VERSION
 
 This program will connect to a Siebel server and exports all components configuration in the form of "create component" commands.
 Those commands can be used with srvrmgr program to recreate those components in another Siebel server. Think of it something like a "Siebel component dumper".
@@ -97,11 +95,11 @@ foreach my $option (qw(s g e u p b r)) {
 
 }
 
-#pulse_start(
-#    name   => 'Connecting to Siebel and getting initial data...',
-#    rotate => 1,
-#    time   => 1
-#) unless ( $opts{q} );
+pulse_start(
+    name   => 'Connecting to Siebel and getting initial data...',
+    rotate => 1,
+    time   => 1
+) unless ( $opts{q} );
 
 my $daemon = Siebel::Srvrmgr::Daemon::Heavy->new(
     {
@@ -140,12 +138,12 @@ my $stash = Siebel::Srvrmgr::Daemon::ActionStash->instance();
 
 $daemon->run();
 
-my $sieb_srv = $stash->shift_stash();
+my $sieb_srv     = $stash->shift_stash();
 my $server_comps = $sieb_srv->get_comps();
 
 my $comp_regex = qr/$opts{r}/;
 
-#pulse_stop() unless ( $opts{q} );
+pulse_stop() unless ( $opts{q} );
 
 my $out;
 
@@ -161,8 +159,8 @@ my $no_match = 1;
 foreach my $comp_alias ( @{$server_comps} ) {
 
     next unless ( $comp_alias =~ $comp_regex );
-	
-	$no_match = 0;
+
+    $no_match = 0;
 
     my $command =
         'list params for server '
@@ -194,7 +192,9 @@ foreach my $comp_alias ( @{$server_comps} ) {
 
     my @params;
 
-    foreach my $param_alias ( keys( %{ $params->{data_parsed} } ) ) {
+    my @sorted = sort( keys( %{ $params->{data_parsed} } ) );
+
+    foreach my $param_alias (@sorted) {
 
         my $param = $params->{data_parsed}->{$param_alias};
 
@@ -236,10 +236,11 @@ foreach my $comp_alias ( @{$server_comps} ) {
 
 close($out) if ( defined($out) );
 
-if ( $no_match ) {
+if ($no_match) {
 
-	warn "Could not match any component alias to the string '$opts{r}'. Removing the output file (probably empty anyway)...";
-	unlink($opts{o}) or die "Cannot remove $opts{o}: $!\n";
+    warn
+"Could not match any component alias to the string '$opts{r}'. Removing the output file (probably empty anyway)...";
+    unlink( $opts{o} ) or die "Cannot remove $opts{o}: $!\n";
 
 }
 
