@@ -43,7 +43,7 @@ use Siebel::Srvrmgr;
 use Scalar::Util qw(weaken);
 use Config;
 use Carp qw(longmess);
-use Socket qw(:crlf);
+use Siebel::Srvrmgr::Types;
 
 our $SIG_INT   = 0;
 our $SIG_PIPE  = 0;
@@ -71,7 +71,7 @@ to the Enterprise only, not specifying which Siebel Server to connect.
 =cut
 
 has server => (
-    isa      => 'Str',
+    isa      => 'NotNullStr',
     is       => 'rw',
     required => 0,
     reader   => 'get_server',
@@ -86,7 +86,7 @@ object creation with the C<new> method.
 =cut
 
 has gateway => (
-    isa      => 'Str',
+    isa      => 'NotNullStr',
     is       => 'rw',
     required => 1,
     reader   => 'get_gateway',
@@ -101,7 +101,7 @@ object creation with the C<new> method.
 =cut
 
 has enterprise => (
-    isa      => 'Str',
+    isa      => 'NotNullStr',
     is       => 'rw',
     required => 1,
     reader   => 'get_enterprise',
@@ -116,7 +116,7 @@ object creation with the C<new> method.
 =cut
 
 has user => (
-    isa      => 'Str',
+    isa      => 'NotNullStr',
     is       => 'rw',
     required => 1,
     reader   => 'get_user',
@@ -131,7 +131,7 @@ object creation with the C<new> method.
 =cut
 
 has password => (
-    isa      => 'Str',
+    isa      => 'NotNullStr',
     is       => 'rw',
     required => 1,
     reader   => 'get_password',
@@ -168,7 +168,7 @@ This is a required attribute during object creation with the C<new> method.
 =cut
 
 has bin => (
-    isa      => 'Str',
+    isa      => 'NotNullStr',
     is       => 'rw',
     required => 1,
     reader   => 'get_bin',
@@ -279,10 +279,50 @@ has retries => (
     default => 0
 );
 
+=head2 clear_raw
+
+A boolean attribute that defines if the raw data recovered from C<srvrmgr> should be kept or discarded as soon as possibly.
+
+Having a default value of true, it should help reducing memory usage or debugging, if set false.
+
+=cut
+
+has clear_raw => (
+    is      => 'rw',
+    isa     => 'Bool',
+    reader  => 'clear_raw',
+    writer  => 'set_clear_raw',
+    default => 1
+);
+
+=head2 field_delimiter
+
+This is a single character attribute. It tells the Daemon class to consider a field delimiter, if such options was
+set in the C<srvrmgr> program. If this option is used but this attribute is not set accordinly, parsing will probably
+fail.
+
+Since this attribute should be defined during Daemon object instance, it is read-only.
+
+=cut
+
+has field_delimiter => ( is => 'ro', isa => 'Chr', reader => 'get_field_del' );
+
 =pod
 
 =head1 METHODS
 
+=head2 get_field_del
+
+Getter for the C<field_delimiter> attribute.
+
+=head2 clear_raw
+
+Getter for the C<clear_raw> attribute.
+
+=head2 set_clear_raw
+
+Setter for the C<clear_raw> attribute.
+
 =head2 get_alarm
 
 Returns the content of the C<alarm_timeout> attribute.
@@ -395,26 +435,6 @@ sub reset_retries {
 
 }
 
-=head2 BUILD
-
-Validate if the parameters gateway, enterprise, user,  password,  server and bin are defined.
-
-=cut
-
-sub BUILD {
-
-    my $self = shift;
-
-    foreach my $attrib (qw(gateway enterprise user password bin)) {
-
-        confess "parameter $attrib must have a defined value"
-          unless ( ( defined( $self->{$attrib} ) )
-            and ( $self->{$attrib} ne '' ) );
-
-    }
-
-}
-
 # for better security
 sub _check_cmd {
 
@@ -507,20 +527,53 @@ sub normalize_eol {
     confess 'data parameter must be an array or scalar reference'
       unless ( ( $ref_type eq 'ARRAY' ) or ( $ref_type eq 'SCALAR' ) );
 
+    my $c_regex = qr/\015?\012/;
+
     if ( $ref_type eq 'ARRAY' ) {
 
-        local $/ = LF;
+        local $/ = \012;
 
         foreach ( @{$data_ref} ) {
 
-            s/$CR?$LF/\n/og;
+            s/$c_regex/\n/g;
 
         }
 
     }
     else {
 
-        $$data_ref =~ s/$CR?$LF/\n/g;
+        $$data_ref =~ s/$c_regex/\n/g;
+
+    }
+
+}
+
+=pod
+
+=head2 create_parser
+
+Returns an instance of a L<Siebel::Srvrmgr::ListParser> class.
+
+=cut
+
+sub create_parser {
+
+    my $self = shift;
+
+    if ( $self->get_field_del() ) {
+
+        return Siebel::Srvrmgr::ListParser->new(
+            {
+                clear_raw       => $self->clear_raw(),
+                field_delimiter => $self->get_field_del()
+            }
+        );
+
+    }
+    else {
+
+        return Siebel::Srvrmgr::ListParser->new(
+            { clear_raw => $self->clear_raw() } );
 
     }
 
@@ -541,8 +594,7 @@ sub _define_params {
     );
 
     push( @params, '/s', $self->get_server() )
-      if (  ( defined( $self->get_server() ) )
-        and ( $self->get_server() ne '' ) );
+      if ( defined( $self->get_server() ) );
 
 # :WORKAROUND:06/08/2013 21:05:32:: if a perlscript will be executed (like for automated testing of this distribution)
 # then the perl interpreter must be part of the command path to avoid calling cmd.exe (in Microsoft Windows)
