@@ -35,7 +35,7 @@ extends 'Siebel::Srvrmgr::Daemon::Action';
 
 =head1 DESCRIPTION
 
-This subclass of L<Siebel::Srvrmgr::Daemon::Action> will try to find a L<Siebel::Srvrmgr::ListParser::Output::ListComp> object in the given array reference
+This subclass of L<Siebel::Srvrmgr::Daemon::Action> will try to find a L<Siebel::Srvrmgr::ListParser::Output::Tabular::ListComp> object in the given array reference
 given as parameter to the C<do> method and compares the status of the components with the array reference given as parameter.
 
 The C<do> method of C<Siebel::Srvrmgr::Daemon::Action::CheckComps> uses L<Siebel::Srvrmgr::Daemon::ActionStash> to enable the program that created the object 
@@ -49,20 +49,16 @@ This module was created to work close with Nagios concepts, especially regarding
 
 The new method returns a instance of L<Siebel::Srvrmgr::Daemon::Action::CheckComps>. The parameter expected are the same ones of any subclass of 
 L<Siebel::Srvrmgr::Daemon::Action>, but the C<params> attribute has a important difference: it expects an array reference with instances of classes
-that have the role L<Siebel::Srvrmgr::Daemon::Action::CheckComps::Server>. The way that the classes will get the 
-information about which component to check per server is not important as long as they keep the same methods defined by 
-the roles L<Siebel::Srvrmgr::Daemon::Action::CheckComps::Server> and 
-L<Siebel::Srvrmgr::Daemon::Action::CheckComps::Component>.
-that have the role L<Siebel::Srvrmgr::Daemon::Action::CheckComps::Server>. The way that the classes will get the information about which component 
-information is available per server is not important as long as they keep the same methods defined by the roles 
-L<Siebel::Srvrmgr::Daemon::Action::CheckComps::Server> for a Siebel server and L<Siebel::Srvrmgr::Daemon::Action::CheckComps::Component> for a Siebel
-server component.
+that have the role L<Siebel::Srvrmgr::Daemon::Action::CheckComps::Server>.
 
-See the examples directory of this distribution to check a XML file used for configuration for more details.
+The server instance itself will expect to have multiple instances of objects representing a Siebel Component and those instances must be of a class that has the 
+Moose role L<Siebel::Srvrmgr::Daemon::Action::CheckComps::Component> applied.
+
+See the C<examples> directory of this distribution, uh, examples of implementation.
 
 =head2 BUILD
 
-Validates if the params array reference have objects with the L<Siebel::Srvrmgr::Daemon::Action::CheckComps::Server> role applied.
+Validates if the params array reference have objects with the L<Siebel::Srvrmgr::Daemon::Action::Check::Server> role applied.
 
 =cut
 
@@ -70,7 +66,7 @@ sub BUILD {
 
     my $self = shift;
 
-    my $role = 'Siebel::Srvrmgr::Daemon::Action::CheckComps::Server';
+    my $role = 'Siebel::Srvrmgr::Daemon::Action::Check::Server';
 
     foreach my $object ( @{ $self->get_params() } ) {
 
@@ -81,11 +77,17 @@ sub BUILD {
 
 }
 
+override '_build_exp_output' => sub {
+
+    return 'Siebel::Srvrmgr::ListParser::Output::Tabular::ListComp';
+
+};
+
 =head2 do_parsed
 
 Expects a array reference as the buffer output from C<srvrmgr> program as a parameter.
 
-This method will check the output from C<srvrmgr> program parsed by L<Siebel::Srvrmgr::ListParser::Output::ListComp> object and compare each component recovered status
+This method will check the output from C<srvrmgr> program parsed by L<Siebel::Srvrmgr::ListParser::Output::Tabular::ListComp> object and compare each component recovered status
 with the status defined in the array reference given to C<params> method during object creation.
 
 It will return 1 if this operation was executed successfuly and request a instance of L<Siebel::Srvrmgr::Daemon::ActionStash>, calling it's method C<instance> and then
@@ -131,13 +133,14 @@ override 'do_parsed' => sub {
 
     my %checked_comps;
 
-    if ( $obj->isa('Siebel::Srvrmgr::ListParser::Output::ListComp') ) {
+    if ( $obj->isa( $self->get_exp_output ) ) {
 
         my $out_servers_ref =
           $obj->get_servers();    # servers retrieve from output of srvrmgr
 
-        confess
-"Could not fetch servers from the Siebel::Srvrmgr::ListParser::Output::ListComp object returned by the parser"
+        $logger->die( 'Could not fetch servers from the '
+              . $self->get_exp_output
+              . 'object returned by the parser' )
           unless ( scalar( @{$out_servers_ref} ) > 0 );
 
         foreach my $out_name ( @{$out_servers_ref} ) {
@@ -236,6 +239,8 @@ override 'do_parsed' => sub {
     }
     else {
 
+        $logger->debug( 'object received ISA not' . $self->get_exp_output() )
+          if ( $logger->is_debug() );
         return 0;
 
     }
@@ -263,11 +268,11 @@ override 'do_parsed' => sub {
 
 =head1 SEE ALSO
 
-=over 4
+=over
 
 =item *
 
-L<Siebel::Srvrmgr::ListParser::Output::ListComp>
+L<Siebel::Srvrmgr::ListParser::Output::Tabular::ListComp>
 
 =item *
 
@@ -289,11 +294,11 @@ L<Nagios::Plugin>
 
 =head1 AUTHOR
 
-Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.org<E<gt>
+Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.org<E<gt>
+This software is copyright (c) 2012 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>
 
 This file is part of Siebel Monitoring Tools.
 
@@ -308,7 +313,7 @@ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
-along with Siebel Monitoring Tools.  If not, see <http://www.gnu.org/licenses/>.
+along with Siebel Monitoring Tools.  If not, see L<http://www.gnu.org/licenses/>.
 
 =cut
 
