@@ -64,7 +64,7 @@ sub BUILD {
 
     }
 
-    my $file = shift( @{$params_ref} );
+    my $file = $params_ref->[0];
 
     if ( ( defined($file) ) and ( $file ne '' ) ) {
 
@@ -87,7 +87,7 @@ L<Siebel::Srvrmgr::Daemon::Action>
 
 =head1 AUTHOR
 
-Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.org<E<gt>
+Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.org<Egt>
 
 =head1 COPYRIGHT AND LICENSE
 
