@@ -69,6 +69,7 @@ use Carp qw(longmess);
 use File::Temp;
 use Data::Dumper;
 use Siebel::Srvrmgr;
+use File::BOM qw(:all);
 
 extends 'Siebel::Srvrmgr::Daemon';
 
@@ -137,7 +138,7 @@ sub run {
     weaken($logger);
     $logger->info('Starting run method');
 
-    my $parser = Siebel::Srvrmgr::ListParser->new();
+    my $parser = $self->create_parser();
 
     if ( $logger->is_debug() ) {
 
@@ -152,9 +153,16 @@ sub run {
 
     $self->_check_system( $logger, ${^CHILD_ERROR_NATIVE}, $ret_code, $? );
 
-    open( my $in, '<', $self->get_output_file() )
-      or
-      $logger->logdie( 'Cannot read ' . $self->get_output_file() . ': ' . $! );
+    my $in;
+    eval { open_bom( $in, $self->get_output_file(), ':utf8' ) };
+
+    if ($@) {
+
+        $logger->logdie(
+            'Cannot read ' . $self->get_output_file() . ': ' . $@ );
+
+    }
+
     my @input_buffer = <$in>;
     close($in);
 
@@ -230,8 +238,6 @@ sub run {
 
 =head2 cmds_vs_tree
 
-Expects the number of parsed nodes as parameter.
-
 This method compares the number of C<commands> defined in a instance of this class with the number of nodes passed as parameter.
 
 If their are equal, the number is returned. If their are different (and there is a problem with the parsed output of srvrmgr) this method
