@@ -21,9 +21,10 @@ use Siebel::Srvrmgr;
 use Log::Log4perl;
 use Scalar::Util qw(weaken);
 use Siebel::Srvrmgr::ListParser::FSA;
-use Socket qw(:crlf);
 use namespace::autoclean;
 use Carp;
+use Siebel::Srvrmgr::Types;
+use String::BOM qw(string_has_bom strip_bom_from_string);
 
 =pod
 
@@ -137,11 +138,17 @@ This object has some details about the enterprise connected. Check the related P
 
 has 'enterprise' => (
     is     => 'ro',
-    isa    => 'Siebel::Srvrmgr::ListParser::Output::Greetings',
+    isa    => 'Siebel::Srvrmgr::ListParser::Output::Enterprise',
     reader => 'get_enterprise',
     writer => '_set_enterprise'
 );
 
+=pod
+
+=head2 fsa
+
+=cut
+
 has 'fsa' => (
     is     => 'ro',
     isa    => 'Siebel::Srvrmgr::ListParser::FSA',
@@ -151,6 +158,22 @@ has 'fsa' => (
 
 =pod
 
+=head2 clear_raw
+
+=cut
+
+has clear_raw => (
+    is      => 'rw',
+    isa     => 'Bool',
+    reader  => 'clear_raw',
+    writer  => 'set_clear_raw',
+    default => 1
+);
+
+has field_delimiter => ( is => 'ro', isa => 'Chr', reader => 'get_field_del' );
+
+=pod
+
 =head1 METHODS
 
 =head2 is_cmd_changed
@@ -204,7 +227,7 @@ sub _toggle_cmd_changed {
 
 =head2 BUILD
 
-Automaticallu defined the state machine object based on L<Siebel::Srvrmgr::ListParser::FSA>.
+Automatically defines the state machine object based on L<Siebel::Srvrmgr::ListParser::FSA>.
 
 =cut
 
@@ -212,7 +235,16 @@ sub BUILD {
 
     my $self = shift;
 
-    $self->_set_fsa( Siebel::Srvrmgr::ListParser::FSA->new() );
+    my $copy_ref = Siebel::Srvrmgr::ListParser::OutputFactory->get_mapping();
+
+    foreach my $cmd_alias ( keys( %{$copy_ref} ) ) {
+
+        my $regex = $copy_ref->{$cmd_alias}->[1];
+        $copy_ref->{$cmd_alias} = $regex;
+
+    }
+
+    $self->_set_fsa( Siebel::Srvrmgr::ListParser::FSA->new($copy_ref) );
 
 }
 
@@ -220,7 +252,7 @@ sub BUILD {
 
 =head2 set_buffer
 
-Sets the buffer attribute,  inserting new C<Siebel::Srvrmgr::ListParser::Buffer> objects into the array reference as necessary.
+Sets the buffer attribute, inserting new C<Siebel::Srvrmgr::ListParser::Buffer> objects into the array reference as necessary.
 
 Expects an instance of a L<FSA::State> class as parameter (obligatory parameter).
 
@@ -305,6 +337,12 @@ sub _create_buffer {
     my $self = shift;
     my $type = shift;
 
+    my $log_cfg = Siebel::Srvrmgr->logging_cfg();
+    confess 'Could not start logging facilities'
+      unless ( Log::Log4perl->init_once( \$log_cfg ) );
+    my $logger = Log::Log4perl->get_logger('Siebel::Srvrmgr::ListParser');
+    weaken($logger);
+
     if ( Siebel::Srvrmgr::ListParser::OutputFactory->can_create($type) ) {
 
         my $buffer = Siebel::Srvrmgr::ListParser::Buffer->new(
@@ -316,6 +354,19 @@ sub _create_buffer {
 
         push( @{ $self->get_buffer() }, $buffer );
 
+        if ( $logger->is_debug ) {
+
+            $logger->debug("Created buffer for $type output");
+
+        }
+
+    }
+    else {
+
+        $logger->fatal(
+"Siebel::Srvrmgr::ListParser::OutputFactory cannot create instances of $type type"
+        );
+
     }
 
 }
@@ -425,16 +476,17 @@ sub append_output {
 
     if ( defined($buffer) ) {
 
-        my $output = Siebel::Srvrmgr::ListParser::OutputFactory->create(
+        my $output = Siebel::Srvrmgr::ListParser::OutputFactory->build(
             $buffer->get_type(),
             {
                 data_type => $buffer->get_type(),
                 raw_data  => $buffer->get_content(),
                 cmd_line  => $buffer->get_cmd_line()
-            }
+            },
+            $self->get_field_del()
         );
 
-        if ( $output->isa('Siebel::Srvrmgr::ListParser::Output::Greetings') ) {
+        if ( $output->isa('Siebel::Srvrmgr::ListParser::Output::Enterprise') ) {
 
             $self->_set_enterprise($output);
 
@@ -453,17 +505,19 @@ sub append_output {
 
         foreach my $buffer ( @{$buffer_ref} ) {
 
-            my $output = Siebel::Srvrmgr::ListParser::OutputFactory->create(
+            my $output = Siebel::Srvrmgr::ListParser::OutputFactory->build(
                 $buffer->get_type(),
                 {
                     data_type => $buffer->get_type(),
                     raw_data  => $buffer->get_content(),
                     cmd_line  => $buffer->get_cmd_line()
-                }
+                },
+                $self->get_field_del()
             );
 
             if (
-                $output->isa('Siebel::Srvrmgr::ListParser::Output::Greetings') )
+                $output->isa('Siebel::Srvrmgr::ListParser::Output::Enterprise')
+              )
             {
 
                 $self->_set_enterprise($output);
@@ -508,11 +562,19 @@ sub parse {
     my $logger = Siebel::Srvrmgr->gimme_logger( ref($self) );
     weaken($logger);
 
-    $logger->logdie( 'Received an invalid buffer as parameter' )
-      unless ( ( defined($data_ref) ) and ( ref($data_ref) eq 'ARRAY' ) and (scalar(@{$data_ref}) > 0) );
+    $logger->logdie('Received an invalid buffer as parameter')
+      unless ( ( defined($data_ref) )
+        and ( ref($data_ref) eq 'ARRAY' )
+        and ( scalar( @{$data_ref} ) > 0 ) );
 
     weaken($data_ref);
 
+    if ( string_has_bom( $data_ref->[0] ) ) {
+
+        $data_ref->[0] = strip_bom_from_string( $data_ref->[0] );
+
+    }
+
     $self->get_fsa->notes( all_data => $data_ref );
     $self->get_fsa->notes( line_num => 0 );
     $self->get_fsa->start() unless ( $self->get_fsa()->curr_state() );
@@ -526,7 +588,7 @@ sub parse {
         if ( defined($state) ) {
 
             my $curr_msg = $state->notes('line');
-			$found_prompt = $state->notes('found_prompt');
+            $found_prompt = $state->notes('found_prompt');
 
 # :TODO:03-10-2013:arfreitas: find a way to keep circular references between the two objects to avoid
 # checking state change everytime with is_cmd_changed
@@ -534,7 +596,7 @@ sub parse {
           SWITCH: {
 
 # :WORKAROUND:03-10-2013:arfreitas: command_submission defines is_cmd_changed but it is not a
-# Siebel::Srvrmgr::ListParser::Output instance, so it's not worth to create a buffer object for it and discard later.
+# Siebel::Srvrmgr::ListParser::Output subclass, so it's not worth to create a buffer object for it and discard later.
 # Anyway, is expected that after a command is submitted, the next message is the output from it and it needs
 # a buffer to be stored
                 if ( $self->get_fsa->prev_state()->name() eq
