@@ -12,6 +12,8 @@ use warnings;
 use strict;
 use MooseX::AbstractFactory;
 use Carp;
+use Siebel::Srvrmgr::Regexes qw(CONN_GREET);
+use Hash::Util qw(lock_hash);
 
 =pod
 
@@ -39,10 +41,18 @@ C<Siebel::Srvrmgr::ListParser::OutputFactory::table_mapping> for the mapping bet
 
 =head1 METHODS
 
-=head2 create
+All methods below are class methods.
+
+=head2 build
 
 Returns the instance of the class defined by the type given as parameter. Expects two parameters: an string with the type
-of output and an hash reference with the parameters expected by the C<new> method of L<Siebel::Srvrmgr::ListParser::Output>.
+of output and an hash reference with the parameters expected by the C<new> method of L<Siebel::Srvrmgr::ListParser::Output> subclasses.
+
+A third, optional parameter, is required if the desired instance is a subclass of L<Siebel::Srvrmgr::ListParser::Output::Tabular>: one must
+pass a single character as the field separator, if exists in the output to be parsed.
+
+Despite using L<MooseX::AbstractFactory> to implement the Abstract Factory pattern, this method must be invoked instead of C<create>
+so the class will be able to make additional checkings necessary to define defaults for subclasses of L<Siebel::Srvrmgr::ListParser::Output::Tabular>.
 
 =head2 can_create
 
@@ -51,9 +61,15 @@ Expects a string as the output type.
 Returns true if there is a mapping between the given type and a subclass of L<Siebel::Srvrmgr::ListParser::Output>;
 otherwise it returns false;
 
+=head2 get_mapping
+
+Returns an hash reference with the mapping between the parsed types and subclasses of L<Siebel::Srvrmgr::ListParser::Ouput>.
+
+The values are array references with the partial classes names and a compiled regular expression to validate the command.
+
 =head1 SEE ALSO
 
-=over 3
+=over
 
 =item *
 
@@ -71,18 +87,28 @@ L<Siebel::Srvrmgr::ListParser>
 
 =cut
 
- # :TODO      :01/07/2013 13:37:06:: create "static" method to return this data
-our %table_mapping = (
-    'list_comp'        => 'ListComp',
-    'list_params'      => 'ListParams',
-    'list_comp_def'    => 'ListCompDef',
-    'greetings'        => 'Greetings',
-    'list_comp_types'  => 'ListCompTypes',
-    'load_preferences' => 'LoadPreferences',
-    'list_tasks'       => 'ListTasks',
-    'list_servers'     => 'ListServers'
+my %table_mapping = (
+    'list_comp'        => ['Tabular::ListComp', qr/^list\scomps?$/],
+    'list_params'      => ['Tabular::ListParams', qr/list\sparam(eter)?s?(\s(\w+\s)?(for\sserver\s\w+)?(\sfor\s((comp(nent)?)|named\ssubsystem|task)\s\w+)?)?/],
+    'list_comp_def'    => ['Tabular::ListCompDef', qr/list\scomp\sdefs?(\s\w+)?/],
+    'greetings'        => ['Enterprise', CONN_GREET],
+    'list_comp_types'  => ['Tabular::ListCompTypes', qr/list\scomp(nent)?\stypes?$/],
+    'load_preferences' => ['LoadPreferences', qr/^load\spreferences$/],
+    'list_tasks'       => ['Tabular::ListTasks', qr/list\stasks(\sfor\sserver\s\w+\scomponent\sgroup?\s\w+)?/],
+    'list_servers'     => ['Tabular::ListServers', qr/list\sserver(s)?.*/],
+    'list_sessions'    => ['Tabular::ListSessions', qr/^list\s(active|hung)?\s?sessions$/]
 );
 
+lock_hash(%table_mapping);
+
+sub get_mapping {
+
+    my %copy = %table_mapping;
+
+    return \%copy;
+
+}
+
 sub can_create {
 
     my $class = shift;
@@ -92,15 +118,43 @@ sub can_create {
 
 }
 
+sub build {
+
+    my $class         = shift;
+    my $last_cmd_type = shift;
+    my $object_data   = shift;    # hash ref
+
+    confess 'object data is required' unless ( defined($object_data) );
+
+    if ( $table_mapping{$last_cmd_type}->[0] =~ /^Tabular/ ) {
+
+        my $field_del = shift;
+
+        if ( defined($field_del) ) {
+
+            $object_data->{col_sep}        = $field_del;
+            $object_data->{structure_type} = 'delimited';
+        }
+        else {
+
+            $object_data->{structure_type} = 'fixed';
+
+        }
+
+    }
+
+    $class->create( $last_cmd_type, $object_data );
+
+}
+
 implementation_class_via sub {
 
     my $last_cmd_type = shift;
-    my $object_data   = shift;    # hash ref
 
     if ( exists( $table_mapping{$last_cmd_type} ) ) {
 
         return 'Siebel::Srvrmgr::ListParser::Output::'
-          . $table_mapping{$last_cmd_type};
+          . $table_mapping{$last_cmd_type}->[0];
 
     }
     else {
