@@ -6,7 +6,7 @@ use File::Spec;
 use Test::Moose 'has_attribute_ok';
 use Siebel::Srvrmgr::Daemon::Heavy;
 use Config;
-use base 'Test::Siebel::Srvrmgr::Daemon';
+use parent 'Test::Siebel::Srvrmgr::Daemon';
 use Siebel::Srvrmgr;
 
 sub class_methods : Test(+1) {
@@ -35,12 +35,10 @@ sub class_methods : Test(+1) {
 
 }
 
-sub class_attributes : Tests(+12) {
+sub class_attributes : Tests(no_plan) {
 
     my $test = shift;
 
-    $test->SUPER::class_attributes();
-
     my @attribs = (
         'write_fh',        'read_fh',
         'child_pid',       'is_infinite',
@@ -50,11 +48,7 @@ sub class_attributes : Tests(+12) {
         'read_timeout',    'child_pid'
     );
 
-    foreach my $attribute (@attribs) {
-
-        has_attribute_ok( $test->{daemon}, $attribute );
-
-    }
+    $test->SUPER::class_attributes(\@attribs);
 
 }
 
